//    This file is part of JustVideo.

//    JustVideo is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.

//    JustVideo is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.

#include "folder_dialog.h"

FolderDialog::FolderDialog(shared_t *conf, bool preFill, QWidget *parent) : QDialog(parent)
{
    shared = conf;

    auto mainLayout = new QVBoxLayout(this);
    auto formWidget = new QWidget(this);
    auto formLayout = new QFormLayout(formWidget);
    auto btnWidget  = new QWidget(this);
    auto btnLayout  = new QHBoxLayout(btnWidget);
    auto okBtn      = new QPushButton(tr("Ok"), this);
    auto cancelBtn  = new QPushButton(tr("Cancel"), this);
    auto browseBtn  = new QToolButton(this);

    folder   = new QLineEdit(this);
    jmFolder = new QCheckBox(this);

    browseBtn->setToolButtonStyle(Qt::ToolButtonTextOnly);
    browseBtn->setText("...");

    formLayout->addRow(new QLabel(tr("Folder:"), this), sideBySide(folder, browseBtn));
    formLayout->addRow(new QLabel(tr("JustMotion:"), this), jmFolder);

    btnLayout->addWidget(okBtn);
    btnLayout->addWidget(cancelBtn);

    mainLayout->addWidget(formWidget, 0, Qt::AlignHCenter);
    mainLayout->addWidget(btnWidget, 0, Qt::AlignHCenter);

    connect(okBtn,     &QPushButton::clicked, this, &FolderDialog::run);
    connect(cancelBtn, &QPushButton::clicked, this, &FolderDialog::reject);
    connect(browseBtn, &QToolButton::clicked, this, &FolderDialog::browse);

    setContentsMargins(0,0,0,0);

    if (preFill)
    {
        QTimer::singleShot(500, this, &FolderDialog::autoRun);
    }
}

void FolderDialog::autoRun()
{
    rd(); run();
}

void FolderDialog::setWidIntoLayout(QWidget *widget, QHBoxLayout *lay, int wid)
{
    if (widget == nullptr)
    {
        auto blank = new QWidget(this);

        if (wid != 0)
        {
            blank->setFixedWidth(wid);
        }

        lay->addWidget(blank);
    }
    else
    {
        if (wid != 0)
        {
            widget->setFixedWidth(wid);
        }

        lay->addWidget(widget);
    }
}

QWidget *FolderDialog::sideBySide(QWidget *left, QWidget *right, int lWid, int rWid)
{
    auto ret = new QWidget(this);
    auto lay = new QHBoxLayout(ret);

    if (left != nullptr)
    {
        left->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
    }

    setWidIntoLayout(left, lay, lWid);
    setWidIntoLayout(right, lay, rWid);

    lay->setSpacing(0);

    return ret;
}

void FolderDialog::rd()
{
    folder->setText(shared->playPath);
    jmFolder->setChecked(shared->isJM);
}

void FolderDialog::wr()
{
    shared->playPath = folder->text();
    shared->isJM     = jmFolder->isChecked();
}

void FolderDialog::errMsg(const QString &shortMsg, const QString &longMsg)
{
    QMessageBox box(this);

    box.setIcon(QMessageBox::Critical);
    box.setText(shortMsg);

    if (!longMsg.isEmpty())
    {
        box.setDetailedText(longMsg);
    }

    box.exec();

    setDisabled(false);
}

void FolderDialog::browse()
{
    auto path = QFileDialog::getExistingDirectory(this, tr("Select a directory"), QDir::homePath(), QFileDialog::ShowDirsOnly);

    if (!path.isEmpty())
    {
        folder->setText(path);
    }
}

void FolderDialog::run()
{
    wr();

    createOrUpdateRecent(shared);

    if (!QFileInfo::exists(shared->playPath))
    {
        errMsg(tr("Folder Non-existant"), tr("Play path '") + shared->playPath + tr("' does not exists"));
    }
    else if (!QFileInfo(shared->playPath).isDir())
    {
        errMsg(tr("Non-directory Error"), tr("Play path '") + shared->playPath + tr("' is not a directory"));
    }
    else
    {
        accept();
    }
}
