//    This file is part of JustVideo.

//    JustVideo is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.

//    JustVideo is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.RPOSE.  See the
//    GNU General Public License for more details.

#include "common.h"
#include "actions.h"
#include "main_widget.h"
#include "recents.h"

int main(int argc, char** argv)
{   
    QApplication app(argc, argv);

    QApplication::setApplicationName(APP_NAME);
    QApplication::setApplicationVersion(APP_VERSION);

    MainGui  mainGui;
    QMenuBar menuBar;
    shared_t shared;

    auto rec = app.primaryScreen()->geometry();

    shared.appDataPath     = QDir::homePath()   + QDir::separator() + "." + QString(APP_TARGET);
    shared.recentsPath     = shared.appDataPath + QDir::separator() + "recent";
    shared.appConfPath     = shared.appDataPath + QDir::separator() + "app.conf";
    shared.windowH         = (rec.height() / 4) * 3;
    shared.windowW         = rec.width() / 2;
    shared.maxRecents      = 20;
    shared.maxViewsPerPage = 4;
    shared.windowX         = rec.x();
    shared.windowY         = rec.y();
    shared.plistX          = 100;
    shared.plistY          = 100;
    shared.plistW          = 550;
    shared.plistH          = shared.windowH;
    shared.retCode         = 0;

    mkPath(shared.appDataPath);
    mkPath(shared.recentsPath);

    if (!QFileInfo::exists(shared.appConfPath))
    {
        wrConf(shared.appConfPath, &shared);
    }

    rdConf(shared.appConfPath, &shared);

    Actions    actions(&shared, &menuBar, &mainGui);
    MainWidget mainWidget(&shared, &menuBar, &mainGui, &actions);

    new RecentsSync(&shared, &actions, &actions);

    mainWidget.setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
    mainWidget.setContentsMargins(0,0,0,0);

    mainGui.setContentsMargins(0,0,0,0);
    mainGui.setCentralWidget(&mainWidget);
    mainGui.setMenuBar(&menuBar);
    mainGui.setWindowTitle(APP_NAME);
    mainGui.setMinimumHeight(600);
    mainGui.setMinimumWidth(800);
    mainGui.setGeometry(shared.windowX, shared.windowY, shared.windowW, shared.windowH);
    mainGui.show();

    auto ret = app.exec();

    rec = mainGui.geometry();

    shared.windowH = rec.height();
    shared.windowW = rec.width();
    shared.windowX = rec.x();
    shared.windowY = rec.y();

    resetSharedRes(&shared);
    wrConf(shared.appConfPath, &shared);

    return ret;
}
