//    This file is part of JustVideo.

//    JustVideo is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.

//    JustVideo is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.

#include "play_control.h"

PlayControl::PlayControl(PlaylistBE *backend, bool pls, Player *media, QVideoWidget *parent) : QDialog(parent)
{
    auto controlsWid    = new QWidget(this);
    auto mainLayout     = new QVBoxLayout(this);
    auto controlsLayout = new QHBoxLayout(controlsWid);

    setModal(true);

    vidName      = new QLabel(this);
    txtPos       = new QLabel(media->getSeekPos(), this);
    playBtn      = new QToolButton(this);
    pauseBtn     = new QToolButton(this);
    nextBtn      = new QToolButton(this);
    prevBtn      = new QToolButton(this);
    plsBtn       = new QToolButton(this);
    fsBtn        = new QToolButton(this);
    backBtn      = new QToolButton(this);
    forwardBtn   = new QToolButton(this);
    hideTimer    = new QTimer(this);
    parentVidWid = parent;

    playBtn->setToolButtonStyle(Qt::ToolButtonTextOnly);
    pauseBtn->setToolButtonStyle(Qt::ToolButtonTextOnly);
    nextBtn->setToolButtonStyle(Qt::ToolButtonTextOnly);
    prevBtn->setToolButtonStyle(Qt::ToolButtonTextOnly);
    plsBtn->setToolButtonStyle(Qt::ToolButtonTextOnly);
    fsBtn->setToolButtonStyle(Qt::ToolButtonTextOnly);

    playBtn->setText(" >");
    pauseBtn->setText("||");
    nextBtn->setText("->");
    prevBtn->setText("<-");
    plsBtn->setText("List");
    fsBtn->setText("[ ]");
    forwardBtn->setText("->(30)");
    backBtn->setText("(10)<-");

    hideTimer->setInterval(5000);
    hideTimer->setSingleShot(true);
    plsBtn->setVisible(pls);
    fsBtn->setCheckable(true);
    fsBtn->setChecked(isFullScreen());

    mainLayout->addWidget(vidName);
    mainLayout->addWidget(controlsWid);

    auto fnt = vidName->font();

    fnt.setFamily("Courier");
    fnt.setBold(true);

    vidName->setFont(fnt);
    playBtn->setFont(fnt);
    pauseBtn->setFont(fnt);
    nextBtn->setFont(fnt);
    prevBtn->setFont(fnt);
    plsBtn->setFont(fnt);
    fsBtn->setFont(fnt);
    forwardBtn->setFont(fnt);
    backBtn->setFont(fnt);

    controlsLayout->addWidget(plsBtn);
    controlsLayout->addWidget(prevBtn);
    controlsLayout->addWidget(playBtn);
    controlsLayout->addWidget(pauseBtn);
    controlsLayout->addWidget(nextBtn);
    controlsLayout->addWidget(fsBtn);
    controlsLayout->addWidget(backBtn);
    controlsLayout->addWidget(txtPos);
    controlsLayout->addWidget(forwardBtn);

    connect(playBtn,  &QToolButton::clicked, backend, &PlaylistBE::play);
    connect(pauseBtn, &QToolButton::clicked, backend, &PlaylistBE::pause);
    connect(nextBtn,  &QToolButton::clicked, backend, &PlaylistBE::next);
    connect(prevBtn,  &QToolButton::clicked, backend, &PlaylistBE::prev);

    connect(hideTimer, &QTimer::timeout,       this, &PlayControl::accept);
    connect(plsBtn,    &QToolButton::clicked,  this, &PlayControl::playlist);
    connect(plsBtn,    &QToolButton::clicked,  this, &PlayControl::accept);
    connect(media,     &Player::stateChanged,  this, &PlayControl::stateChanged);
    connect(media,     &Player::sourceChanged, this, &PlayControl::vidSrcChanged);

    connect(forwardBtn, &QToolButton::clicked, media, &Player::forward);
    connect(backBtn,    &QToolButton::clicked, media, &Player::back);

    connect(fsBtn, &QToolButton::clicked, parent, &QVideoWidget::setFullScreen);

    connect(media, &Player::seekPos, txtPos, &QLabel::setText);

    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);

    stateChanged(media->state());
    vidSrcChanged(media->source());
}

void PlayControl::leaveEvent(QEvent *event)
{
    Q_UNUSED(event);

    accept();
}

void PlayControl::showEvent(QShowEvent *event)
{
    Q_UNUSED(event);

    hideTimer->start();
}

void PlayControl::stateChanged(QAVPlayer::State newState)
{
    if (newState == QAVPlayer::PlayingState)
    {
        playBtn->setVisible(false);
        pauseBtn->setVisible(true);
    }
    else
    {
        playBtn->setVisible(true);
        pauseBtn->setVisible(false);
    }
}

void PlayControl::vidSrcChanged(const QString &path)
{
    vidName->setText(QFileInfo(path).baseName());
}

void PlayControl::resetHide()
{
    hideTimer->start();
}
