#ifndef PLAYER_H
#define PLAYER_H

//    This file is part of JustVideo.

//    JustVideo is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.

//    JustVideo is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.

#include "common.h"

class AudioOut : public QAVAudioOutput
{
    Q_OBJECT

public slots:

    void playFrame(const QAVAudioFrame &frame);

public:

    explicit AudioOut(QObject *parent);
};

class FrameFilter : public QObject
{
    Q_OBJECT

public:

    virtual void procFrame(QVideoFrame *frame, quint64 tPos, quint64 dur) {Q_UNUSED(frame); Q_UNUSED(tPos); Q_UNUSED(dur);}

    explicit FrameFilter(QObject *parent);
};

class Player : public QAVPlayer
{
    Q_OBJECT

private:

    QList<FrameFilter*> frameFilters;
    AudioOut           *audOutput;
    QWidget            *viewWid;
    QVideoSink         *vidSink;
    QTimer             *timer;
    quint64             curPos;

    QString posDurToTxt(qint64 pos, qint64 dur);

private slots:

    void setVideoFrame(const QAVVideoFrame &frame);
    void timeout();
    void initTimer();
    void setupAudio();

public slots:

    void setFile(const QString &path);
    void tooglePlayPause();
    void kill();
    void forward();
    void back();

public:

    void    addFrameFilter(FrameFilter *filter);
    QString getSeekPos();

    explicit Player(QVideoSink *videoSink, bool muted, QWidget *parent);

    ~Player();

signals:

    void seekPos(const QString &txt);
};

#endif // PLAYER_H
