#ifndef PLAYLIST_BACKEND_H
#define PLAYLIST_BACKEND_H

//    This file is part of JustVideo.

//    JustVideo is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.

//    JustVideo is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.

#include "common.h"
#include "player.h"

class PlaylistBE : public QObject
{
    Q_OBJECT

private:

    QStringList fileList;
    QString     vidDir;
    QTimer     *timer;
    shared_t   *shared;
    Player     *player;
    bool        startOnMoreMedia;
    bool        buffer;
    bool        live;
    int         vidClipBuffer;
    int         sliderPos;
    int         index;

    QString seek(char direction);
    void    buffOrEnd();

private slots:

    void scan();
    void init();
    void mediaStatusChanged(QAVPlayer::MediaStatus status);
    void stateChanged(QAVPlayer::State newState);

public slots:

    void next();
    void front();
    void prev();
    void list();
    void start();
    void play();
    void pause();
    void stop();
    void kill();

public:

    explicit PlaylistBE(shared_t *share, const QString &path, Player *media, bool frontPlay, QObject *parent = nullptr);

signals:

    void fileDel(const QString &path);
    void newFile(const QString &path);
    void playFile(const QString &path);
    void playbackResumed();
    void buffering();
    void noMedia();
    void endOfList();
    void mPlay();
    void mPause();
    void mStop();
};

#endif // PLAYLIST_BACKEND_H
