#ifndef PLAYLIST_WIDGET_H
#define PLAYLIST_WIDGET_H

//    This file is part of JustVideo.

//    JustVideo is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.

//    JustVideo is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.

#include "common.h"
#include "img_loader.h"
#include "player.h"
#include "playlist_backend.h"

class PlaylistItem : public QLabel
{
    Q_OBJECT

private:

    ImgLoader *imgLoader;
    QLabel    *image;
    QLabel    *title;
    QDialog   *popMsg;
    QLabel    *popMsgText;
    QString    vidFile;
    QString    imgFile;

    void mouseReleaseEvent(QMouseEvent *event);
    void leaveEvent(QEvent *event);
    void enterEvent(QEnterEvent *event);
    void genImgAndText();
    void dispText();
    bool findImg(QString &pathWithoutExt);

public slots:

    void rmVid(const QString &path);

public:

    explicit PlaylistItem(const QString &filePath, ImgLoader *img, QWidget *parent);

signals:

    void playItemSelected(const QString &fileUrl);
    void aboutToDelete(const QWidget *item);
};

class PlaylistWidget : public QScrollArea
{
    Q_OBJECT

private:

    shared_t       *shared;
    Player         *player;
    QGridLayout    *listLayout;
    ImgLoader      *imgLoader;
    PlaylistBE     *bkend;
    QStringList     fileList;
    QList<QWidget*> widList;

    void reGrid();
    void showEvent(QShowEvent *event);
    void closeEvent(QCloseEvent *event);
    void resizeEvent(QResizeEvent *event);

private slots:

    void addVid(const QString &path);
    void rmVid(const QString &path);
    void rmItem(const QWidget *item);
    void closeWid();

public:

    explicit PlaylistWidget(shared_t *share, PlaylistBE *backend, Player *media, QAction *closeAction, QWidget *parent);

    ~PlaylistWidget();

signals:

    void list();
    void closed(bool checked);
};

#endif // PLAYLIST_WIDGET_H
