//    This file is part of JustVideo.

//    JustVideo is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.

//    JustVideo is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.

#include "recents.h"

RecentItem::RecentItem(const QString &path, Actions *acts, QObject *parent) : QObject(parent)
{
    confPath   = path;
    actions    = acts;
    itemAction = new QAction(genItemName(), this);

    actions->recents->insertAction(actions->recentsSpacer, itemAction);

    connect(itemAction, &QAction::triggered, this, &RecentItem::triggered);
}

QString RecentItem::genItemName()
{
    QString  ret = "Null";
    shared_t conf;

    if (rdConf(confPath, &conf))
    {
        ret = conf.playPath;
    }

    return ret;
}

void RecentItem::triggered()
{
    actions->openConf(confPath);
}

RecentsSync::RecentsSync(shared_t *sharedRes, Actions *acts, QObject *parent) : QObject(parent)
{
    actions = acts;
    share   = sharedRes;

    mon.addPath(share->recentsPath);

    connect(&mon, &QFileSystemWatcher::directoryChanged, this, &RecentsSync::scan);

    scan();
}

void RecentsSync::scan()
{
    emit sync();

    actions->rebuildRecents();

    for (auto &&file: lsConfFiles(share->recentsPath))
    {
        auto item = new RecentItem(share->recentsPath + QDir::separator() + file, actions, this);

        connect(this, &RecentsSync::sync, item, &RecentItem::deleteLater);
    }
}
