//    This file is part of JustVideo.

//    JustVideo is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.

//    JustVideo is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.

#include "vid_grid.h"

VidGrid::VidGrid(shared_t *share, QList<shared_t> confs, const QString &mntLoc, int pageNum, QMenu *camSelect, QAction *closeAction, QStackedWidget *parent) : QWidget(parent)
{
    mainGui    = parent;
    widCount   = 0;
    viewIndex  = parent->addWidget(this);
    mainLayout = new QGridLayout(this);
    menuOption = camSelect->addAction(tr("Grid - Page") + QString::number(pageNum), this, &VidGrid::viewSelected);

    mainLayout->setSpacing(0);

    for (auto &&conf: confs)
    {
        auto vid = new VidWidget(share, conf.camName, QDir::cleanPath(mntLoc + QDir::separator() + conf.buffPath + QDir::separator() + "live"), true, false, nullptr, closeAction, parent);

        connect(this, &VidGrid::stop,  vid, &VidWidget::stop);
        connect(this, &VidGrid::front, vid, &VidWidget::front);

        connect(vid, &VidWidget::destroyed, this, &VidGrid::widCountMinusOne);

        widList.append(vid);

        widCount++;
    }

    connect(closeAction, &QAction::triggered, this, &VidGrid::closeWid);

    setContentsMargins(0,0,0,0);
    connect(parent, &QStackedWidget::currentChanged, this, &VidGrid::viewChanged);
    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
    buildGrid(mainLayout, parent->width(), widList, 500);
}

void VidGrid::widCountMinusOne()
{
    widCount--;

    if (widCount == 0)
    {
        deleteLater();
    }
}

void VidGrid::closeWid()
{
    widList.clear();
}

void VidGrid::viewSelected()
{
    mainGui->setCurrentWidget(this);
}

void VidGrid::viewChanged(int index)
{
    if (!widList.isEmpty())
    {
        if (viewIndex == index)
        {
            emit front();

            menuOption->setIcon(QIcon("://icons/check.png"));
        }
        else
        {
            emit stop();

            menuOption->setIcon(QIcon());
        }
    }
}

void VidGrid::resizeEvent(QResizeEvent *event)
{
    buildGrid(mainLayout, mainGui->width(), widList, 500);

    QWidget::resizeEvent(event);
}
