#ifndef VID_WIDGET_H
#define VID_WIDGET_H

//    This file is part of JustVideo.

//    JustVideo is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.

//    JustVideo is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.

#include "common.h"
#include "playlist_widget.h"
#include "playlist_backend.h"
#include "play_control.h"
#include "player.h"

class VidWidget : public QVideoWidget
{
    Q_OBJECT

private:

    shared_t       *shared;
    QAction        *menuOption;
    QStackedWidget *mainGui;
    PlaylistBE     *playlistBE;
    PlaylistWidget *playlistWid;
    Player         *player;
    QLabel         *txtPos;
    QLabel         *vidName;
    QLabel         *popMsgText;
    QDialog        *popMsg;
    bool            inGrid;
    bool            live;
    bool            ctrlOpen;
    int             viewIndex;
    int             objCount;

    QPoint getCtrlPopPnt();
    void   dispMsg(const QString &txt);
    void   mouseReleaseEvent(QMouseEvent *event);
    void   keyPressEvent(QKeyEvent *event);
    bool   eventFilter(QObject *obj, QEvent *event);

private slots:

    void viewSelected();
    void viewChanged(int index);
    void buffering();
    void endOfList();
    void noMedia();
    void resumed();
    void objKilled();
    void controlsClosed();
    void popCtrl(const QPointF &pnt);
    void hideMain(bool fsState);

public:

    explicit VidWidget(shared_t *share, const QString &camName, const QString &playpath, bool multiLive, bool footage, QMenu *camSelect, QAction *closeAction, QStackedWidget *parent);

signals:

    void start();
    void stop();
    void front();
    void back();
    void forward();
    void togglePlay();
    void closeControls();
    void extendControls();
    void mainWindowsVis(bool);
};

#endif // VID_WIDGET_H
